@@ -7,7 +7,6 @@ import PIL.Image as Image
 import matplotlib.pyplot as plt
 
 Image.MAX_IMAGE_PIXELS = 933120000 # Change the max pixels to avoid warnings
-#lbldict = {1: 'Ramnit', 2:'Lollipop', 3:'Kelihos_ver3', 4:'Vundo', 5:'Simda', 6:'Tracur', 7:'Kelihos_ver1', 8:'Obfuscator.ACY', 9:'Gatak'}
 
 # src = Path to the folder containing the files you want to become images. dst = Path to folder where you want the images saved.
 def convertToImage(src, dst):
@@ -28,13 +27,20 @@ def convertToImage(src, dst):
         img = Image.fromarray(g)
         img.save(dstPath)
     print('Files converted successfully')
-
-# csv = Path to train csv file, path = path to train images, validpct = percent of data for validation, label_col = column number for labels in csv, splitter = how the data should be splitted for train/validation, item_tfms = item transforms for data augmentation, device = what device should be used (cpu/gpu)
-# Returns the DataLoaders
-def loadData(csv, path, validpct=None, label_col=1, seed=None, splitter=None, item_tfms = None, device = None):
-    df = pd.read_csv(csv, sep=',', header=0)
-    dls = ImageDataLoaders.from_df(df, path, label_col=label_col, valid_pct=validpct, seed=seed, splitter = splitter, item_tfms = item_tfms, device=device)
-    return dls
+    
+def loadData(valid_pct, get_items=get_image_files, get_y = parent_label, item_tfms = Resize(224, ResizeMethod.Pad, pad_mode='zeros')):
+    # parent_label -->> simply gets the name of the folder a file is in
+    loader = DataBlock(
+        blocks = (ImageBlock, CategoryBlock),
+        get_items = get_items,
+        splitter = RandomSplitter(valid_pct=valid_pct, seed=24),
+        get_y = get_y,
+        #item_tfms = Resize(224, ResizeMethod.Pad, pad_mode='zeros'),   
+        #RandomResizedCrop(224), # by default it crops
+        item_tfms = item_tfms,
+        batch_tfms=aug_transforms()
+    )
+    return loader
 
 # dls = DataLoaders object, arch = architecture, path = path to where the trained model should be exported, epoch_ct = number of iterations, metrics = the metrics used to train the model, pretrained = whether or not to use a pretrained model (False = Create model from scratch)
 def trainModel(dls, arch, path, epoch_ct=1, metrics=error_rate, pretrained=True):
@@ -66,15 +72,36 @@ def showImages(item):
     plt.axis('off')
     plt.title(item)
     plt.show()
+    
+def confusionMatrix(model):
+    interp = ClassificationInterpretation.from_learner(model)
+    interp.plot_confusion_matrix()
+    plt.show()
 
-# model = the trained model, testPath = the path containing the test set of images, lbl_dict = the dictionary containing the labels
-def predict(model, testPath, lbl_dict, test_df=None):
-    files = os.listdir(testPath)
-    for item in files:
-        # Predict each file
-        pred, pred_idx, probs = model.predict(testPath+item)
-        if(test_df is None):
-            print(f"Item: {item} | Prediction: {lbl_dict[int(pred)]}; Probability: {probs[pred_idx]:.04f}")
-        elif(test_df is not None):
-           print(f"Item: {item} | Prediction: {lbl_dict[int(pred)]}; Probability: {probs[pred_idx]:.04f} | Actual: {lbl_dict[test_df.loc[item][0]]}")
-        #showImges(testPath+item)
+# model = the trained model, testPath = the path containing the test set of images, lbl_dict = the dictionary containing the labels, test_df = test set dataframe showing the actual class for each item
+def predict(model, testPath):
+    global modelaccuracy
+    global modeltotal
+    modelaccuracy = 0
+    modeltotal = 0
+    path = Path(testPath)
+    dirs = os.listdir(path)
+    if(os.path.isdir(testPath+dirs[0])):
+        for dir in dirs: 
+            files = get_image_files(Path(testPath+dir))
+            for item in files:
+                # Predict each file
+                pred, pred_idx, probs = model.predict(item)
+                print(f"Item: {item} | Prediction: {pred}; Probability: {probs[pred_idx]:.04f}")
+                if(pred == parent_label(item)):
+                    modelaccuracy += 1
+                modeltotal += 1
+        try:
+            print("Total Accuracy", str((modelaccuracy/modeltotal) * 100)+"%")
+        except:
+            pass
+    else:
+        files = get_image_files(Path(testPath))
+        for item in files:
+            pred, pred_idx, probs = model.predict(item)
+            print(f"Item: {item} | Prediction: {pred}; Probability: {probs[pred_idx]:.04f}")
